pub fn run_command_status(cmd: &mut Command) -> Result<ExitStatus>Expand description
Run a command and wait for status, optionally logging it to stderr if verbose mode is enabled.
pub fn run_command_status(cmd: &mut Command) -> Result<ExitStatus>Run a command and wait for status, optionally logging it to stderr if verbose mode is enabled.